@@ -72,6 +72,7 @@ class TickTimer:
 				funcs.append ((func, args))
 		for func, args in funcs:
 			func (*args)
+		return now
 
 class Maintern:
 	def __init__ (self):
@@ -192,7 +193,7 @@ def loop (timeout = 30.0):
 
 	_polling = 0
 
-poll_fun = asyncore.poll
+poll_fun = asyncore.poll if '__pypy__' in sys.builtin_module_names else asyncore.epoll
 
 def remove_notsocks (map):
 	global _select_errors, _logger
@@ -242,6 +243,7 @@ def poll_fun_wrap (timeout, map = None):
 
 	try:
 		poll_fun (timeout, map)
+
 	except (TypeError, OSError) as why:
 		# WSAENOTSOCK
 		remove_notsocks (map)
@@ -276,10 +278,10 @@ def lifetime_loop (timeout = 30.0, count = 0):
 	while map and _shutdown_phase == 0:
 		poll_fun_wrap (timeout, map)
 		tick_timer.tick ()
-		now = time.time()
+		now = time.time ()
 		if (now - _last_maintern) > _maintern_interval:
 			maintern (now)
-			_last_maintern = time.time ()
+			_last_maintern = now
 		loop += 1
 		if count and loop > count:
 			break
